@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: setup.py 10584 2017-11-30 09:12:40Z Bear $
+# $Id: setup.py 10719 2018-01-07 08:03:23Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and 
 # limitations under the License.
 #
-# $Author: Bear $
-# $Date: 2017-11-30 17:12:40 +0800 (週四, 30 十一月 2017) $
-# $Revision: 10584 $ 
+# $Author: Lavender $
+# $Date: 2018-01-07 16:03:23 +0800 (週日, 07 一月 2018) $
+# $Revision: 10719 $ 
 
 import os
 import sys
@@ -30,6 +30,47 @@ logger.addHandler(handler)
 
 SETUP_DIR = os.path.dirname(os.path.abspath(__file__))
 
+CMS_EXTRA_PLUGIN = \
+'''
+INSTALLED_APPS += (
+    'djangocms_history', 
+    'djangocms_forms',
+    'djangocms_file',
+    'djangocms_picture',
+)
+'''
+
+CKEDITOR_SETTINGS = \
+'''
+CKEDITOR_SETTINGS = {
+    'language': '{{ language }}',
+    'toolbar_CMS': [
+        ['cmsplugins',],
+        
+        ['Source', '-', 'Save', 'NewPage', 'DocProps', 'Preview', 
+         'Print', '-', ' Templates'],
+        ['Cut', 'Copy', 'Paste', 'PasteText', 'PasteFromWord', '-', 
+         'Undo', 'Redo'],
+        ['Find', 'Replace', '-', 'SelectAll', '-', 'SpellChecker', 
+         'Scayt'],
+        ['Form', 'Checkbox', 'Radio', 'TextField', 'Textarea', 'Select', 
+        'Button', 'ImageButton', 'HiddenField'],
+        ['Bold', 'Italic', 'Underline', 'Strike', 'Subscript', 
+        'Superscript', '-', 'RemoveFormat'],
+        ['NumberedList', 'BulletedList', '-', 'Outdent', 'Indent', '-', 
+        'Blockquote', 'CreateDiv', '-', 'JustifyLeft', 'JustifyCenter', 
+        'JustifyRight', 'JustifyBlock', '-', 'BidiLtr', 'BidiRtl'],
+        ['Link', 'Unlink', 'Anchor'],
+        ['Image', 'Flash', 'Table', 'HorizontalRule', 'Smiley', 
+        'SpecialChar', 'PageBreak', 'Iframe'],
+        ['Styles', 'Format', 'Font', 'FontSize'],
+        ['TextColor', 'BGColor'],
+        ['Maximize', 'ShowBlocks', '-', 'About'],
+    ],
+    'skin': 'moono',
+}
+'''
+
 def copyToPath(baseDir, templateDir, staticDir, mode):
     if not templateDir:
         templateDir = os.path.join(baseDir, 'templates')
@@ -93,7 +134,8 @@ def findSettings(path):
                 return os.path.join(root, f)
     return None
                 
-def writeSettings(settingsPath, templateDir, staticDir, hasCmsTemplate):
+def writeSettings(settingsPath, templateDir, staticDir, hasCmsTemplate, 
+                  wizard=False, createProject=False):
     logger.info("-----Start write and backup settings.py-----")
     def getCMSTemplates():
         templates = []
@@ -104,6 +146,8 @@ def writeSettings(settingsPath, templateDir, staticDir, hasCmsTemplate):
         for template in os.listdir(path):
             if "_user" in template:
                 continue
+            if "_tracking" in template:
+                continue
             if template.lower() == 'index.html':
                 index = template
                 continue
@@ -152,16 +196,55 @@ if DEBUG:
 else:
     STATIC_ROOT = os.path.join(BASE_DIR, 'static')
 '''
-        
+        if createProject:
+            if wizard:
+                if sys.version_info.major == 3:
+                    yesOrNo = input(
+                        "Do you want to install djangocms_history and "
+                        "all ckeditor features?[yes/no]")
+                else:
+                    yesOrNo = raw_input(
+                        "Do you want to install djangocms_history and "
+                        "all ckeditor features?[yes/no]")
+            else:
+                yesOrNo = 'yes'
+                    
+            if yesOrNo == 'yes':
+                addPlugin = True
+                try:
+                    import djangocms_history
+                    import djangocms_file
+                    import djangocms_picture
+                    import djangocms_forms
+                except Exception as e:
+                    result = os.system("pip install djangocms-history")
+                    result = os.system("pip install djangocms-file")
+                    result = os.system("pip install djangocms-picture")
+                    result = os.system("pip install djangocms-forms")
+                    
+                    if result != 0:
+                        addPlugin = False
+                        
+                if addPlugin:
+                    content += CMS_EXTRA_PLUGIN
+                content += CKEDITOR_SETTINGS
         settings.write(content)
+            
+                
     logger.info("Succeed to write settings.py")
                 
 def loadData(baseDir, language):
     logger.info("-----Start load data-----")
     data = os.path.join(".", 'fixtures', 'initial_data.json')
+    result = os.system("%s manage.py migrate" % sys.executable)
+    if not result == 0:
+        logger.error("Can not migrate db.")
+        return False
+        
     result = os.system("%s manage.py loaddata \"%s\"" % (sys.executable, data))
     
     if not result == 0:
+        logger.error("Can not loaddata.")
         return False
     
     from cms.models.pagemodel import Page
@@ -210,6 +293,8 @@ if __name__ == "__main__":
     
     settingsPath = findSettings(path)
     
+    createProject = False
+    
     if not settingsPath:
         try:
             import djangocms_installer
@@ -223,13 +308,17 @@ if __name__ == "__main__":
                 sys.exit(1)
         
         if sys.version_info.major == 3:
+            print()
             projectName = input(
                 "Django project not found. "
-                "Auto create one by djangocms-installer. Input a project name:")
+                "Auto create one by djangocms-installer."
+                "\nPlease input a project name:")
         else:
+            print
             projectName = raw_input(
                 "Django project not found. "
-                "Auto create one by djangocms-installer. Input a project name:")
+                "Auto create one by djangocms-installer."
+                "\nPlease input a project name:")
         path = os.path.join(path, projectName)
         
         if wizard:
@@ -238,6 +327,8 @@ if __name__ == "__main__":
         else:
             result = os.system(
                 "djangocms -f -p \"%s\" \"%s\"" % (path, projectName))
+        
+        createProject = True
             
         if not result == 0:
             print
@@ -335,7 +426,8 @@ if __name__ == "__main__":
         hasCmsTemplate = False
         
     writeSettings(settingsPath, 
-        templateDir, staticDir, hasCmsTemplate)
+        templateDir, staticDir, hasCmsTemplate, 
+        wizard=wizard, createProject=createProject)
         
     os.chdir(baseDir)
         
